import functools


def dict_zip(*dictionaries):
    common_keys = functools.reduce(lambda x, y: x | y,
                                   (set(d.keys()) for d in dictionaries),
                                   set())
    return {
        key: tuple(d[key] for d in dictionaries)
        for key in common_keys
        if all(key in d for d in dictionaries)
    }


def dict_zip_longest(*dictionaries, fillvalue=None):
    common_keys = functools.reduce(lambda x, y: x | y,
                                   (set(d.keys()) for d in dictionaries),
                                   set())
    return {
        key: tuple(d.get(key, fillvalue) for d in dictionaries)
        for key in common_keys
    }



from setuptools import setup


setup(
    name='dict_zip',
    version='0.1.0',
    description='zip and zip_longest for dict',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Yui Kitsu',
    author_email='kitsuyui+github@kitsuyui.com',
    url='https://github.com/kitsuyui/dict_zip',
    packages=[
        'dict_zip',
    ],
    package_dir={
        'dict_zip': 'dict_zip',
    },
    package_data={
        '': ['README.md', 'LICENSE'],
        'dict_zip': ['py.typed'],
    },
    install_requires=[],
    extras_require={},
    tests_require=[],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: BSD License',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries',
    ],
    test_suite='tests',
    license='BSD-3-Clause',
)
